%define fname   SDL

%define	lib_name_orig	lib%{fname}
%global major 0
%define apiver 1.2
#define libname %mklibname SDL %major
#define devname %mklibname -d SDL
%define libname %mklibname %{fname} %{apiver} %{major}
%define devname %mklibname %{fname} -d


%bcond_with static

Name:           sdl12-compat
Version:        1.2.68
Release:        %mkrel 2
Summary:        SDL 1.2 runtime compatibility library using SDL 2.0
Group:		System/Libraries
Epoch:		1

# mp3 decoder code is MIT-0/PD
# SDL_opengl.h is zlib and MIT
License:        zlib and (Public Domain or MIT-0) and MIT
URL:            https://github.com/libsdl-org/sdl12-compat
Source0:        %{url}/archive/release-%{version}/%{name}-%{version}.tar.gz

# Backports from upstream (0001~0500)

# Proposed patches (0501~1000)


BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  git-core
BuildRequires:  make
BuildRequires:  SDL2-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)

%description
Simple DirectMedia Layer (SDL) is a cross-platform multimedia library
designed to provide fast access to the graphics frame buffer and audio device.

This code is a compatibility layer; it provides a binary-compatible API for
programs written against SDL 1.2, but it uses SDL 2.0 behind the scenes.

If you are writing new code, please target SDL 2.0 directly and do not use
this layer.

%package -n %{libname}
Summary: SDL 1.2 runtime compatibility library using SDL 2.0
Group: System/Libraries
Provides:	%{name} = %{version}-%{release}
Provides:       SDL = %{version}
Provides:       SDL%{?_isa} = %{version}
# This dlopens SDL2 (?!), so manually depend on it
Requires:	%{mklibname sdl 2.0 0} >= 2.0.18

%description -n %{libname}
Simple DirectMedia Layer (SDL) is a cross-platform multimedia library
designed to provide fast access to the graphics frame buffer and audio device.

This code is a compatibility layer; it provides a binary-compatible API for
programs written against SDL 1.2, but it uses SDL 2.0 behind the scenes.

If you are writing new code, please target SDL 2.0 directly and do not use
this layer.


%package -n %{devname}
Summary:        Files to develop SDL 1.2 applications using SDL 2.0
Group:		Development/C
Requires:       %{libname}%{?_isa} = %{epoch}:%{version}-%{release}
Provides:       SDL-devel = %{version}
Provides:       SDL-devel%{?_isa} = %{version}
Provides:	%{lib_name_orig}-devel = 1.2.50
Provides:	SDL-devel = 1.2.50
Provides:	SDL%{apiver}-devel = 1.2.50
# Add deps required to compile SDL apps
## For SDL_opengl.h
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
## For SDL_syswm.h
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xproto)
%if %{without static}
Obsoletes:	%{_lib}SDL-static-devel < 1.2.50
%endif

%description -n %{devname}
Simple DirectMedia Layer (SDL) is a cross-platform multimedia library
designed to provide fast access to the graphics frame buffer and audio device.

This code is a compatibility layer; it provides a source-compatible API for
programs written against SDL 1.2, but it uses SDL 2.0 behind the scenes.

If you are writing new code, please target SDL 2.0 directly and do not use
this layer.


%if %{with static}
%package static
Summary:        Static library to develop SDL 1.2 applications using SDL 2.0
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}
# This replaces SDL-static
Obsoletes:      SDL-static < 1.2.15-49
Conflicts:      SDL-static < 1.2.50
Provides:       SDL-static = %{version}
Provides:       SDL-static%{?_isa} = %{version}

%description static
Simple DirectMedia Layer (SDL) is a cross-platform multimedia library
designed to provide fast access to the graphics frame buffer and audio device.

This code is a compatibility layer; it provides a static link library for
programs written against SDL 1.2, but it uses SDL 2.0 behind the scenes.
Note that applications that use this library will need to declare SDL2 as
a dependency manually, as the library is dlopen()'d to preserve APIs between
SDL-1.2 and SDL-2.0.

If you are writing new code, please target SDL 2.0 directly and do not use
this layer.
%endif


%prep
%autosetup -n %{name}-release-%{version} -S git_am


%build
%cmake %{?with_static:-DSTATICDEVEL=ON}
%cmake_build


%install
%cmake_install

%if ! %{with static}
# Delete leftover static files
rm -rf %{buildroot}%{_libdir}/*.a
%endif


%files -n %{libname}
%license LICENSE.txt
%doc README.md BUGS.md COMPATIBILITY.md
%{_libdir}/libSDL-1.2.so.*

%files -n %{devname}
%{_bindir}/sdl-config
%{_datadir}/aclocal/sdl.m4
%{_includedir}/SDL/
%{_libdir}/libSDL-1.2.so
%{_libdir}/libSDL.so
%{_libdir}/pkgconfig/sdl12_compat.pc

%if %{with static}
%files static
%{_libdir}/libSDL.a
%{_libdir}/libSDLmain.a
%endif


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 1:1.2.68-2.mga10
+ Revision: 2218720
- Mageia 10 Mass Rebuild

* Thu Sep 28 2023 tv <tv> 1:1.2.68-1.mga10
+ Revision: 1992013
- Update to 1.2.68

* Thu Nov 17 2022 tv <tv> 1:1.2.60-4.mga9
+ Revision: 1908480
- Fix perl-SDL testsuite hanging since 1.2.56

* Thu Nov 17 2022 tv <tv> 1:1.2.60-3.mga9
+ Revision: 1908455
- Make static option to work, do not package *.a by default

* Sat Nov 05 2022 tv <tv> 1:1.2.60-2.mga9
+ Revision: 1903697
- fix SDL12COMPAT_MAX_VIDMODE

* Thu Nov 03 2022 ghibo <ghibo> 1:1.2.60-1.mga9
+ Revision: 1902117
- Update to release 1.2.60

* Mon Sep 19 2022 luigiwalser <luigiwalser> 1:1.2.56-1.mga9
+ Revision: 1890636
- 1.2.56

* Fri Apr 01 2022 umeabot <umeabot> 1:1.2.52-2.mga9
+ Revision: 1839063
- Mageia 9 Mass Rebuild

* Sat Mar 05 2022 tv <tv> 1:1.2.52-1.mga9
+ Revision: 1789099
- Update to 1.2.52

* Mon Nov 29 2021 tv <tv> 1:0.0.1~git.20211125.4e4527a-1.mga9
+ Revision: 1759816
- Update to new snapshot release

* Mon Nov 08 2021 tv <tv> 1:0.0.1~git.20211107.a10d6b6-1.mga9
+ Revision: 1754732
- Update to new snapshot release

* Tue Oct 12 2021 tv <tv> 1:0.0.1~git.20210926.c6cfc8f-1.mga9
+ Revision: 1750639
- Update to new snapshot release

* Sat Aug 28 2021 tv <tv> 1:0.0.1~git.20210825.b5f7170-1.mga9
+ Revision: 1743277
- Update to new snapshot release

* Tue Jul 27 2021 tv <tv> 1:0.0.1~git.20210719.aa9919b-1.mga9
+ Revision: 1737946
- Update to new snapshot release

* Sun Jul 18 2021 tv <tv> 1:0.0.1~git.20210709.51254e5-1.mga9
+ Revision: 1736861
- Update to new snapshot release

* Tue Jun 29 2021 tv <tv> 1:0.0.1~git.20210628.cf47f88-1.mga9
+ Revision: 1734329
- Update to new snapshot release

* Mon Jun 21 2021 tv <tv> 1:0.0.1~git.20210619.4ad7ba6-2.mga9
+ Revision: 1731577
- Update devel dependencies based on upstream feedback
- Update to new snapshot release
- Add devel dependencies expected by SDL packages to devel subpackage

* Tue Jun 15 2021 tv <tv> 1:0.0.1~git.20210612.44f299f-2.mga9
+ Revision: 1730831
- Update to new snapshot release
- Update license tag information

* Tue Jun 15 2021 wally <wally> 1:0.0.1~git.20210609.efe9791-2.mga9
+ Revision: 1730811
- drop old static devel pkg from SDL12

* Wed Jun 09 2021 ngompa <ngompa> 1:0.0.1~git.20210609.efe9791-1.mga9
+ Revision: 1730216
- Update to new snapshot release
- Sync fixes from Fedora package
+ wally <wally>
- fix lib pkg sumamry

* Fri Jun 04 2021 tv <tv> 1:0.0.1~git.20210602.cc5826a-3.mga9
+ Revision: 1729733
- imported package sdl12-compat


* Fri Jun 04 2021 Thierry Vignaud <tv@mageia.org> 0.0.1~git.20210602.cc5826a-3.mga9
- Initial package
